==================================================
``psyclone.psyir.nodes.array_of_structures_mixin``
==================================================

.. automodule:: psyclone.psyir.nodes.array_of_structures_mixin

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.array_of_structures_mixin


Classes
=======

- :py:class:`ArrayOfStructuresMixin`:
  Abstract class used to extend the ArrayMixin class with functionality


.. autoclass:: ArrayOfStructuresMixin
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ArrayOfStructuresMixin
      :parts: 1
